@@ -30,6 +30,11 @@
 #include "capplet-util.h"
 #include "gconf-property-editor.h"
 
+enum
+{
+	RESPONSE_APPLY = 1,
+	RESPONSE_CLOSE
+};
 
 static GConfEnumStringPair toolbar_style_enums[] = {
   { 0, "both" },
@@ -66,16 +71,11 @@ toolbar_to_widget (GConfValue *value)
 
 
 static void
-dialog_button_clicked_cb (GnomeDialog *dialog, gint response_id, GConfChangeSet *changeset) 
+dialog_button_clicked_cb (GtkDialog *dialog, gint response_id, GConfChangeSet *changeset) 
 {
   switch (response_id)
     {
-    case GTK_RESPONSE_APPLY:
-      gconf_client_commit_change_set (gconf_client_get_default (), changeset, TRUE, NULL);
-      break;
-    case GTK_RESPONSE_HELP:
-      break;
-    case GTK_RESPONSE_CLOSE:
+    case RESPONSE_CLOSE:
     case GTK_RESPONSE_DELETE_EVENT:
     default:
       gtk_main_quit ();
@@ -122,11 +122,12 @@ int
 main (int argc, char **argv)
 {
   GConfClient    *client;
+  GConfChangeSet *changeset = NULL;
   GladeXML       *dialog;
 
-  bindtextdomain (PACKAGE, GNOMELOCALEDIR);
-  bind_textdomain_codeset (PACKAGE, "UTF-8");
-  textdomain (PACKAGE);
+  bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+  textdomain (GETTEXT_PACKAGE);
 
   gnome_program_init (argv[0], VERSION, LIBGNOMEUI_MODULE, argc, argv,
 		      GNOME_PARAM_APP_DATADIR, GNOMECC_DATA_DIR,
@@ -136,7 +137,7 @@ main (int argc, char **argv)
   gconf_client_add_dir (client, "/desktop/gnome/interface", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
 
   dialog = create_dialog ();
-  setup_dialog (dialog, NULL);
+  setup_dialog (dialog, changeset);
 
   gtk_main ();
 
